@@ -117,18 +117,18 @@ namespace Oxygen
         _treeViewStateEngine->setEnabled( animationsEnabled && settings.genericAnimationsEnabled() );
         _treeViewStateEngine->setDuration( settings.genericAnimationsDuration() );
 
-        _menuBarStateEngine->setAnimationsEnabled( animationsEnabled && (settings.menuBarAnimationType() != None) );
+        _menuBarStateEngine->setAnimationsEnabled( animationsEnabled && (settings.menuBarAnimationType() != NoAnimation) );
         _menuBarStateEngine->setFollowMouse( settings.menuBarAnimationType() == FollowMouse );
         _menuBarStateEngine->setDuration( settings.menuBarAnimationsDuration() );
         _menuBarStateEngine->setFollowMouseAnimationsDuration( settings.menuBarFollowMouseAnimationsDuration() );
 
-        _menuStateEngine->setEnabled( animationsEnabled && (settings.menuAnimationType() != None) );
+        _menuStateEngine->setEnabled( animationsEnabled && (settings.menuAnimationType() != NoAnimation) );
         _menuStateEngine->setFollowMouse( settings.menuAnimationType() == FollowMouse );
         _menuStateEngine->setDuration( settings.menuAnimationsDuration() );
         _menuStateEngine->setFollowMouseAnimationsDuration( settings.menuFollowMouseAnimationsDuration() );
 
         // for now, only Fade animations mode is supported for toolbar animations
-        _toolBarStateEngine->setEnabled( animationsEnabled && (settings.toolBarAnimationType() != None) );
+        _toolBarStateEngine->setEnabled( animationsEnabled && (settings.toolBarAnimationType() != NoAnimation) );
         _toolBarStateEngine->setFollowMouse(  settings.toolBarAnimationType() == FollowMouse );
         _toolBarStateEngine->setDuration( settings.genericAnimationsDuration() );
         _toolBarStateEngine->setFollowMouseAnimationsDuration( settings.toolBarAnimationsDuration() );
