@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -20,6 +20,8 @@
 
 #include "oxygenmenustatedata.h"
 #include "../oxygengtkutils.h"
+#include "../oxygenmetrics.h"
+#include "../config.h"
 
 #include <cassert>
 #include <gtk/gtk.h>
@@ -32,21 +34,15 @@ namespace Oxygen
     void MenuStateData::connect( GtkWidget* widget )
     {
 
+        #if OXYGEN_DEBUG
+        std::cerr
+            << "Oxygen::MenuStateData::connect - "
+            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
+            << std::endl;
+        #endif
+
         _target = widget;
 
-        // save paddings
-        if( GTK_IS_MENU( widget ) )
-        {
-            gtk_widget_style_get( _target,
-                "vertical-padding", &_yPadding,
-                "horizontal-padding", &_xPadding,
-                NULL );
-        }
-
-        // connect signals
-        _motionId.connect( G_OBJECT(widget), "motion-notify-event", G_CALLBACK( motionNotifyEvent ), this );
-        _leaveId.connect( G_OBJECT(widget), "leave-notify-event", G_CALLBACK( leaveNotifyEvent ), this );
-
         // connect timeLines
         _current._timeLine.connect( (GSourceFunc)delayedUpdate, this );
         _previous._timeLine.connect( (GSourceFunc)delayedUpdate, this );
@@ -64,124 +60,104 @@ namespace Oxygen
     void MenuStateData::disconnect( GtkWidget* widget )
     {
 
-        _target = 0L;
+        #if OXYGEN_DEBUG
+        std::cerr
+            << "Oxygen::MenuStateData::disconnect - "
+            << " " << _target << " (" << (_target ? G_OBJECT_TYPE_NAME( _target ) : "0x0") << ")"
+            << std::endl;
+        #endif
 
-        // disconnect signal
-        _motionId.disconnect();
-        _leaveId.disconnect();
+        _target = 0L;
 
         // disconnect timelines
         _current._timeLine.disconnect();
         _previous._timeLine.disconnect();
         _timer.stop();
 
+        // disconnect all children
+        for( ChildrenMap::iterator iter = _children.begin(); iter != _children.end(); ++iter )
+        { iter->second.disconnect(); }
+
+        _children.clear();
+
         // base class
         FollowMouseData::disconnect();
 
    }
 
     //________________________________________________________________________________
-    void MenuStateData::updateItems( void )
+    void MenuStateData::registerChild( GtkWidget* widget )
     {
-
-        if( !_target ) return;
-
-        GdkWindow* window( gtk_widget_get_window( _target ) );
-        GdkWindow* childWindow( 0L );
-
-        // get mouse pointer position
-        gint xPointer(0), yPointer(0);
-        GdkDeviceManager* manager( gdk_display_get_device_manager( gtk_widget_get_display( _target ) ) );
-        GdkDevice* pointer( gdk_device_manager_get_client_pointer( manager ) );
-        gdk_window_get_device_position( window, pointer, &xPointer, &yPointer, 0L);
-
-        // reset offset
-        int xOffset(0);
-        int yOffset(0);
-
-        bool delayed( false );
-        bool activeFound( false );
-        GList *children( gtk_container_get_children( GTK_CONTAINER( _target ) ) );
-        for( GList* child = g_list_first(children); child; child = g_list_next(child) )
+        if( widget && _children.find( widget ) == _children.end() )
         {
 
-            if( !( child->data && GTK_IS_MENU_ITEM( child->data ) ) ) continue;
-
-            GtkWidget* childWidget( GTK_WIDGET( child->data ) );
-            const GtkStateFlags state( gtk_widget_get_state_flags( childWidget ) );
-
-            // do nothing for disabled child
-            const bool active( !( state&GTK_STATE_FLAG_INSENSITIVE || GTK_IS_SEPARATOR_MENU_ITEM( childWidget ) ) );
-
-            // update offsets
-            if( childWindow != gtk_widget_get_window( childWidget ) )
-            {
-
-                childWindow = gtk_widget_get_window( childWidget );
-                Gtk::gdk_window_translate_origin( window, childWindow, &xOffset, &yOffset );
-
-            }
-
-            // get allocation and add offsets
-            GtkAllocation allocation( Gtk::gtk_widget_get_allocation( childWidget ) );
-            allocation.x += xOffset;
-            allocation.y += yOffset;
-
-            if( Gtk::gdk_rectangle_contains( &allocation, xPointer, yPointer ) )
-            {
-
-                if( active )
-                {
-
-                    activeFound = true;
-                    if( !(state&GTK_STATE_FLAG_PRELIGHT) )
-                    { updateState( childWidget, Gtk::gtk_widget_get_allocation( childWidget ), xOffset, yOffset, true ); }
-
-                } else delayed = true;
-
-                break;
-
-            }
+            #if OXYGEN_DEBUG
+            std::cerr
+                << "Oxygen::MenuStateData::registerChild -"
+                << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
+                << std::endl;
+            #endif
 
+            Signal destroyId;
+            destroyId.connect( G_OBJECT( widget ), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
+            _children.insert( std::make_pair( widget, destroyId ) );
         }
 
-        if( children ) g_list_free( children );
+    }
 
-        // fade-out current
-        if( _current.isValid() && !activeFound && !menuItemIsActive( _current._widget ) )
-        { updateState( _current._widget, _current._rect, _current._xOffset, _current._yOffset, false, delayed ); }
+    //________________________________________________________________________________
+    void MenuStateData::unregisterChild( GtkWidget* widget )
+    {
 
-        return;
+        #if OXYGEN_DEBUG
+        std::cerr
+            << "Oxygen::MenuStateData::unregisterChild -"
+            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
+            << std::endl;
+        #endif
+
+        ChildrenMap::iterator iter( _children.find( widget ) );
+
+        // erase from children map
+        if( iter != _children.end() )
+        {
+            iter->second.disconnect();
+            _children.erase( iter );
+        }
+
+        // reset corresponding data, if matches
+        if( widget == _previous._widget )
+        {
+            _previous._widget = 0L;
+            _previous._timeLine.disconnect();
+        }
+
+        if( widget == _current._widget )
+        {
+            _current._widget = 0L;
+            _current._timeLine.disconnect();
+        }
 
     }
 
     //________________________________________________________________________________
-    bool MenuStateData::menuItemIsActive( GtkWidget* widget ) const
-    {
-
-        // check argument
-        if( !GTK_IS_MENU_ITEM( widget ) ) return false;
-
-        // check menu
-        GtkWidget* menu( gtk_menu_item_get_submenu( GTK_MENU_ITEM( widget ) ) );
-        if( !GTK_IS_MENU( menu ) ) return false;
-
-        GtkWidget* topLevel( gtk_widget_get_toplevel( menu ) );
-        if( !topLevel ) return false;
-
-        return
-            gtk_widget_get_visible( menu ) &&
-            gtk_widget_get_realized( topLevel ) &&
-            gtk_widget_get_visible( topLevel );
-    }
-
-    //________________________________________________________________________________
-    bool MenuStateData::updateState( GtkWidget* widget, const GdkRectangle& rect, int xOffset, int yOffset, bool state, bool delayed )
+    bool MenuStateData::updateState( GtkWidget* widget, bool state, bool delayed )
     {
 
+        registerChild( widget );
         if( state && widget != _current._widget )
         {
 
+            // get window offset
+            GdkWindow* window( gtk_widget_get_window( _target ) );
+            GdkWindow* childWindow( gtk_widget_get_window( widget ) );
+            int xOffset(0);
+            int yOffset(0);
+            Gtk::gdk_window_translate_origin( window, childWindow, &xOffset, &yOffset );
+
+            // get allocation
+            const GdkRectangle rect( Gtk::gtk_widget_get_allocation( widget ) );
+
             // stop timer
             if( _timer.isRunning() ) _timer.stop();
 
@@ -217,7 +193,7 @@ namespace Oxygen
                 else delayedUpdate( this );
             }
 
-            return true;
+            return false;
 
         } else if( !state && widget == _current._widget ) {
 
@@ -240,6 +216,8 @@ namespace Oxygen
                 if( !_timer.isRunning() )
                 { _timer.start( _timeOut, (GSourceFunc)delayedAnimate, this ); }
 
+                return true;
+
             } else {
 
                 if( _timer.isRunning() ) _timer.stop();
@@ -248,9 +226,10 @@ namespace Oxygen
                 if( _previous.isValid() && gtk_widget_get_state_flags( _previous._widget )&GTK_STATE_FLAG_PRELIGHT )
                 { _previous._timeLine.start(); }
 
+                return false;
+
             }
 
-            return true;
 
         } else return false;
 
@@ -293,10 +272,6 @@ namespace Oxygen
 
                 // no valid offset found. Add full allocation
                 followMouseRect = Gtk::gtk_widget_get_allocation( _target );
-                followMouseRect.x += _xPadding;
-                followMouseRect.y += _yPadding;
-                followMouseRect.width -= 2*_xPadding;
-                followMouseRect.height -= 2*_yPadding;
 
             }
 
@@ -310,17 +285,16 @@ namespace Oxygen
 
     }
 
-    //________________________________________________________________________________
-    gboolean MenuStateData::motionNotifyEvent(GtkWidget*, GdkEventMotion*, gpointer pointer )
+    //____________________________________________________________________________________________
+    gboolean MenuStateData::childDestroyNotifyEvent( GtkWidget* widget, gpointer data )
     {
-        static_cast<MenuStateData*>( pointer )->updateItems();
-        return FALSE;
-    }
-
-    //________________________________________________________________________________
-    gboolean MenuStateData::leaveNotifyEvent( GtkWidget*, GdkEventCrossing*, gpointer pointer )
-    {
-        static_cast<MenuStateData*>( pointer )->updateItems();
+        #if OXYGEN_DEBUG
+        std::cerr
+            << "Oxygen::MenuStateData::childDestroyNotifyEvent -"
+            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
+            << std::endl;
+        #endif
+        static_cast<MenuStateData*>(data)->unregisterChild( widget );
         return FALSE;
     }
 
@@ -329,16 +303,15 @@ namespace Oxygen
     {
 
         MenuStateData& data( *static_cast<MenuStateData*>( pointer ) );
-
         if( data._target )
         {
             GdkRectangle rect( data.dirtyRect() );
 
-            const int margin( 2 );
-            rect.x -= margin;
-            rect.y -= margin;
-            rect.width += 2*margin;
-            rect.height += 2*margin;
+            // enlarge rect by margin
+            rect.x -= Menu_Margin;
+            rect.y -= Menu_Margin;
+            rect.width += 2*Menu_Margin;
+            rect.height += 2*Menu_Margin;
 
             Gtk::gtk_widget_queue_draw( data._target, &rect );
         }
@@ -352,18 +325,24 @@ namespace Oxygen
     {
 
         MenuStateData& data( *static_cast<MenuStateData*>( pointer ) );
-
         if( data._target && data.followMouse() )
         {
 
+            #if OXYGEN_DEBUG
+            std::cerr
+                << "Oxygen::MenuStateData::followMouseUpdate -"
+                << " " << data._target << " (" << G_OBJECT_TYPE_NAME( data._target ) << ")"
+                << std::endl;
+            #endif
+
             data.updateAnimatedRect();
             GdkRectangle rect( data.dirtyRect() );
 
-            const int margin( 2 );
-            rect.x -= margin;
-            rect.y -= margin;
-            rect.width += 2*margin;
-            rect.height += 2*margin;
+            // padding must match gtk.css file
+            rect.x -= Menu_Margin;
+            rect.y -= Menu_Margin;
+            rect.width += 2*Menu_Margin;
+            rect.height += 2*Menu_Margin;
 
             Gtk::gtk_widget_queue_draw( data._target, &rect );
 
