@@ -2,7 +2,7 @@
 #define oxygenmenustatedata_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -43,9 +43,7 @@ namespace Oxygen
         //! constructor
         MenuStateData( void ):
             _target( 0L ),
-            _dirtyRect( Gtk::gdk_rectangle() ),
-            _xPadding(0),
-            _yPadding(0)
+            _dirtyRect( Gtk::gdk_rectangle() )
             {}
 
         //! destructor
@@ -88,6 +86,9 @@ namespace Oxygen
             _previous._timeLine.setDuration( value );
         }
 
+        //! update state for given widget
+        bool updateState( GtkWidget*, bool state, bool delayed = false );
+
         //@}
 
         //!@name accessors
@@ -132,15 +133,6 @@ namespace Oxygen
         //! disconnect child
         void unregisterChild( GtkWidget* );
 
-        //! update items
-        void updateItems( void );
-
-        //! update state for given widget
-        bool updateState( GtkWidget*, const GdkRectangle&, int, int, bool state, bool delayed = false );
-
-        //! true if menu item is active (pressed down)
-        bool menuItemIsActive( GtkWidget* ) const;
-
         //! return dirty rect (for update)
         GdkRectangle dirtyRect( void );
 
@@ -241,12 +233,6 @@ namespace Oxygen
         //! child is destroyed
         static gboolean childDestroyNotifyEvent( GtkWidget*, gpointer );
 
-        //! mouse motion events
-        static gboolean motionNotifyEvent( GtkWidget*, GdkEventMotion*, gpointer);
-
-        //! mouse leave events
-        static gboolean leaveNotifyEvent( GtkWidget*, GdkEventCrossing*, gpointer);
-
         //! update widget for fade-in/fade-out animation
         static gboolean delayedUpdate( gpointer );
 
@@ -263,12 +249,6 @@ namespace Oxygen
         //! target
         GtkWidget* _target;
 
-        //!@name signals
-        //@{
-        Signal _motionId;
-        Signal _leaveId;
-        //@}
-
         //!@name animation data
         //@{
 
@@ -283,10 +263,6 @@ namespace Oxygen
         //!@name follow mouse animated data
         //@{
 
-        //! padding
-        gint _xPadding;
-        gint _yPadding;
-
         //! delayed animation timeOut
         static const int _timeOut;
 
