@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * inspired notably from kdelibs/kdeui/color/kcolorutils.h
 * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
@@ -242,7 +242,7 @@ namespace Oxygen
 
     //_________________________________________________________________________
     ColorUtils::Rgba ColorUtils::decoColor( const ColorUtils::Rgba& background, const ColorUtils::Rgba& color )
-    { return mix( background, color, 0.4 + 0.8*contrast() ); }
+    { return mix( background, color, 0.8*(1.0 + contrast() ) ); }
 
     //_________________________________________________________________________
     ColorUtils::Rgba ColorUtils::alphaColor( const ColorUtils::Rgba& color, double alpha )
