@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * inspired notably from kdelibs/kdeui/color/kcolorutils.h
 * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
@@ -27,10 +27,70 @@
 #include "config.h"
 
 #include <iostream>
+#include <fstream>
 
 namespace Oxygen
 {
 
+    //_________________________________________________________
+    OptionMap::OptionMap( const std::string& filename )
+    {
+
+        std::ifstream in( filename.c_str() );
+        if( !in ) return;
+
+        std::string currentSection;
+        std::string currentLine;
+        while( std::getline( in, currentLine, '\n' ) )
+        {
+
+            if( currentLine.empty() ) continue;
+
+            // check if line is a section
+            if( currentLine[0] == '[' )
+            {
+
+                size_t end( currentLine.rfind( ']' ) );
+                if( end == std::string::npos ) continue;
+                currentSection = currentLine.substr( 0, end+1 );
+
+            } else if( currentSection.empty() ) {
+
+                continue;
+
+            }
+
+            // check if line is a valid option
+            size_t mid( currentLine.find( '=' ) );
+            if( mid == std::string::npos ) continue;
+
+            // insert new option in map
+            Option option( currentLine.substr( 0, mid ), currentLine.substr( mid+1 ) );
+
+            #if OXYGEN_DEBUG
+            option.setFile( filename );
+            #endif
+
+            (*this)[currentSection].insert( option );
+
+        }
+
+    }
+
+    //_________________________________________________________
+    bool OptionMap::operator == (const OptionMap& other ) const
+    {
+        const_iterator firstIter( begin() );
+        const_iterator secondIter( other.begin() );
+        for(;firstIter != end() && secondIter != other.end(); ++firstIter, ++secondIter )
+        {
+            if( !( firstIter->first == secondIter->first && firstIter->second == secondIter->second ) )
+            { return false; }
+        }
+
+        return firstIter == end() && secondIter == other.end();
+    }
+
     //_________________________________________________________
     OptionMap& OptionMap::merge( const OptionMap& other )
     {
